==> matchprobes_1.0.0.tar.gz: matchprobes/R/makeProbePackage.R <==
##----------------------------------------------------------------------
## Copyright R. Gentleman and W. Huber, 2003, all rights reserved
##----------------------------------------------------------------------
makeProbePackage <- function(arraytype,
          importfun = "getProbeDataAffy",
          maintainer,
          version,
          pkgname = NULL,
          outdir  = ".",
          force = FALSE, quiet = FALSE, check = TRUE, build = TRUE, unlink = TRUE, ...)
{
  ## Bureucracy: check arguments
  if (missing(maintainer) || !is.character(maintainer))
    stop(paste("'maintainer' is missing or invalid. Please specify the maintainer of the",
               "package that you want to create in the form: Your name <you@domain>", sep="\n"))
  if (missing(version) || !is.character(version))
    stop(paste("'version' is missing or invalid. Please select a version number larger",
               "than those used for any previous versions of this package.", sep="\n"))
  if(!exists(importfun) || !is.function(get(importfun)))
    stop("'importfun' must be a function.")

  ## Call the import function
  ## importRes is a list with three elements:
  ## $pkgname : package name
  ## $dataEnv : environment containing data objects
  ## $symVal  : named list with symbol-value substitutions
  if (!quiet) cat("Importing the data.\n")
  importRes = do.call(importfun, c(arraytype = arraytype, pkgname = pkgname, list(...)))

  pkgname = importRes$pkgname
  thispkg = "matchprobes"
  desc    = package.description(thispkg)[c("Package", "Version")]
  creator = paste("package", desc[1], "version", desc[2])

  symbolValues = c(importRes$symVal, list(
    VERSION    = version,
    CREATOR    = creator,
    MAINTAINER = maintainer))

  ## Create package
  createRes = createPackage(pkgname,
    destinationDir = outdir,
    originDir = file.path(.path.package(thispkg), "Code"),
    symbolValues = symbolValues,
    unlink = unlink, quiet = quiet)

  ## Write the data objects
  if (!quiet) cat("Writing the data.\n")
  save(list  = ls(importRes$dataEnv),
       file  = file.path(createRes$pkgdir, "data", paste(pkgname, ".rda", sep="")),
       envir = importRes$dataEnv)

  ## R CMD check
  cdir <- getwd()
  setwd(outdir)
  on.exit(setwd(cdir))
  if (check) {
    if (!quiet)
      cat("Checking the package.\n")
    system(paste(file.path(R.home(),"bin","R"), "CMD check",
                 pkgname))
    logFile = file.path(paste(pkgname, "Rcheck", sep="."), "00check.log")
    if (!file.exists(logFile)) {
      stop(paste("Expected but did not find the log-file", logFile, "after R CMD check"))
    } else {
      thelines = readLines(logFile)
      warns = grep("WARNING", thelines, value=TRUE)
      errs  = grep("ERROR", thelines, value=TRUE)
      if (length(warns)>0)
        cat("*** WARNINGS ***\n", warns)
      if (length(errs)>0)
        stop(errs)
    }
    if (unlink)
      unlink(paste(pkgname, ".Rcheck", sep=""), recursive = TRUE)
  }

  ## R CMD build
  if (build) {
    if (!quiet)
      cat("Building the package.\n")
    system(paste(file.path(R.home(),"bin","R"), "CMD build",
                 ifelse(force, "-force", ""),
                 pkgname))
  }
  setwd(cdir)
  return(pkgname)
}

==> matchprobes_1.0.8.tar.gz: matchprobes/R/makeProbePackage.R <==
##----------------------------------------------------------------------
## Copyright R. Gentleman and W. Huber, 2003, all rights reserved
##----------------------------------------------------------------------
makeProbePackage <- function(arraytype,
          importfun = "getProbeDataAffy",
          maintainer,
          version,
          pkgname = NULL,
          outdir  = ".",
          force = FALSE, quiet = FALSE, check = TRUE, build = TRUE, unlink = TRUE, ...)
{
  ## Bureucracy: check arguments
  if (missing(maintainer) || !is.character(maintainer))
    stop(paste("'maintainer' is missing or invalid. Please specify the maintainer of the",
               "package that you want to create in the form: Your name <you@domain>", sep="\n"))
  if (missing(version) || !is.character(version))
    stop(paste("'version' is missing or invalid. Please select a version number larger",
               "than those used for any previous versions of this package.", sep="\n"))
  if(!exists(importfun) || !is.function(get(importfun)))
    stop("'importfun' must be a function.")

  ## Call the import function
  ## importRes is a list with three elements:
  ## $pkgname : package name
  ## $dataEnv : environment containing data objects
  ## $symVal  : named list with symbol-value substitutions
  if (!quiet) cat("Importing the data.\n")
  importRes <- do.call(importfun, c(arraytype = arraytype, pkgname = pkgname, list(...)))

  pkgname <- importRes$pkgname
  thispkg <- "matchprobes"
  desc    <- packageDescription(thispkg)

  stopifnot(desc$Package ==thispkg)
  thispkgVers <- desc$Version
  
  symbolValues <- c(importRes$symVal, list(
    VERSION            = version,
    CREATOR            = paste("package", thispkg, "version", thispkgVers),
    MATCHPROBESVERSION = thispkgVers,                                      
    MAINTAINER         = maintainer))

  ## Create package
  createRes <- createPackage(pkgname,
    destinationDir = outdir,
    originDir = file.path(.path.package(thispkg), "Code"),
    symbolValues = symbolValues,
    unlink = unlink, quiet = quiet)

  ## Write the data objects
  if (!quiet) cat("Writing the data.\n")
  save(list  = ls(importRes$dataEnv),
       file  = file.path(createRes$pkgdir, "data", paste(pkgname, ".rda", sep="")),
       envir = importRes$dataEnv)

  ## R CMD check
  cdir <- getwd()
  setwd(outdir)
  on.exit(setwd(cdir))
  if (check) {
    if (!quiet)
      cat("Checking the package.\n")
    system(paste(file.path(R.home(),"bin","R"), "CMD check",
                 pkgname))
    logFile <- file.path(paste(pkgname, "Rcheck", sep="."), "00check.log")
    if (!file.exists(logFile)) {
      stop(paste("Expected but did not find the log-file", logFile, "after R CMD check"))
    } else {
      thelines <- readLines(logFile)
      warns <- grep("WARNING", thelines, value=TRUE)
      errs  <- grep("ERROR", thelines, value=TRUE)
      if (length(warns)>0)
        cat("*** WARNINGS ***\n", warns)
      if (length(errs)>0)
        stop(errs)
    }
    if (unlink)
      unlink(paste(pkgname, ".Rcheck", sep=""), recursive = TRUE)
  }

  ## R CMD build
  if (build) {
    if (!quiet)
      cat("Building the package.\n")
    system(paste(file.path(R.home(),"bin","R"), "CMD build",
                 ifelse(force, "-force", ""),
                 pkgname))
  }
  setwd(cdir)
  return(pkgname)
}
